@@ -206,17 +206,23 @@ def mask_where_too_few_values(Nmin, N, x):
 def double_precision(a):
     '''
 '''
-    if a.dtype.kind == 'f':
+    char = a.dtype.char
+    if char == 'f':
         newtype = float
-    elif a.dtype.kind == 'i':
+    elif char == 'i':
         newtype = int
+    else:
+        return a
+#    print 'DCH a.shape, a.dtype =',a.shape, a.dtype, newtype
+    try:
+        print 'a[10, 10, 10, 10] =',a[10, 10, 10, 10]
+    except:
+        pass
 
     if numpy_ma_isMA(a):
-        a = a.astype(newtype)
+        return a.astype(newtype)
     else:
-        a = a.astype(newtype, copy=False)
-
-    return a
+        return a.astype(newtype, copy=False)
 #--- End: def
 
 #---------------------------------------------------------------------
@@ -366,6 +372,7 @@ The weighted average along the specified axes.
         3-tuple.
 
 '''
+#    print 'DCH in mean_f'
     a = double_precision(a)
 
     if masked:
@@ -909,7 +916,7 @@ def var_ffinalise(out, sub_samples=None):
                    ccc &= numpy.isclose(nwmax, nwmax.astype(int), rtol=1e-05, atol=1e-08)
                    ccc &= numpy.isclose(nsw  , nsw.astype(int)  , rtol=1e-05, atol=1e-08)
                    m = numpy_where(ccc, n, m)
-                   print 'rase', m.min()
+#                   print 'DCH rase', m.min()
                    if m.min():
                        # Every element of m has been set (to an integer
                        # greater than 1), so we are done.
