@@ -15,10 +15,10 @@ from .um.read     import read as um_read
 from .um.read     import is_um_file
 
 def read(files, verbose=False, ignore_read_error=False,
-         aggregate=True, umversion=4.5, nfields=None, squeeze=False,
+         aggregate=True, sion=4.5, nfields=None, squeeze=False,
          unsqueeze=False, fmt=None, select=None, select_options={},
          top_level=None, height_at_top_of_model=None, recursive=False,
-         follow_symlinks=False):
+         follow_symlinks=False, um=None):
     '''Read fields from files into `cf.Field` objects.
 
 A file may be on disk or on a OPeNDAP server.
@@ -236,10 +236,6 @@ Office (UK) fields files format files may be read.
 
     aggregate_options['copy'] = False
     
-    # Parse umversion
-    if umversion is not None:
-        umversion = float(str(umversion).replace('.', '0', 1))
-
     # ----------------------------------------------------------------
     # Parse top_level
     # ----------------------------------------------------------------
@@ -302,8 +298,8 @@ Office (UK) fields files format files may be read.
                                   verbose=verbose,
                                   aggregate=aggregate,
                                   aggregate_options=aggregate_options,
-                                  umversion=umversion,
                                   selected_fmt=fmt,
+                                  um=um,
                                   promote=promote,
                                   height_at_top_of_model=height_at_top_of_model)
             
@@ -404,8 +400,8 @@ def _read_a_file(filename,
                  aggregate_options={},
                  ignore_read_error=False,
                  verbose=False,
-                 umversion=None,
                  selected_fmt=None,
+                 um=None,
                  promote=(),
                  height_at_top_of_model=None):
     '''
@@ -446,15 +442,28 @@ Read the contents of a single file into a field list.
 
 '''
     # Find this file's type
-    try:
-        ftype = file_type(filename)        
-    except Exception as error:
-        if ignore_read_error: 
-            if verbose:
-                print('WARNING: %s' % error)
-            return FieldList()
-        raise error
-    #--- End: try
+    fmt       = None
+    word_size = None
+    endian    = None
+    umversion = 405
+    if um:
+        ftype = 'UM' 
+        fmt       = um.get('fmt')
+        word_size = um.get('word_size')
+        endian    = um.get('endian')
+        umversion = um.get('version')
+        if umversion is not None:
+            umversion = float(str(umversion).replace('.', '0', 1))
+    else:
+        try:
+            ftype = file_type(filename)        
+        except Exception as error:
+            if ignore_read_error: 
+                if verbose:
+                    print('WARNING: %s' % error)
+                return FieldList()
+            raise Exception(error)
+    #--- End: if
 
     # ----------------------------------------------------------------
     # Still here? Read the file into fields.
@@ -466,7 +475,8 @@ Read the contents of a single file into a field list.
     elif ftype == 'UM' and (selected_fmt in (None, 'PP', 'FF')):
         fields = um_read(filename, um_version=umversion,
                          verbose=verbose, set_standard_name=False,
-                         height_at_top_of_model=height_at_top_of_model)
+                         height_at_top_of_model=height_at_top_of_model,
+                         fmt=fmt, word_size=word_size, endian=endian)
 
         # PP fields are aggregated intrafile prior to interfile
         # aggregation
@@ -533,5 +543,5 @@ def file_type(filename):
     # ----------------------------------------------------------------
 
     # Still here?
-    raise IOError("File %s has unsupported format" % filename)
+    raise IOError("Can't determine format of file {}".format(filename))
 #--- End: def
