@@ -36,6 +36,7 @@ class DataTest(unittest.TestCase):
 #    test_only = ('test_Data_sums_of_weights',)
 #    test_only = ('test_Data_sample_size','test_Data_sd_var')
 #    test_only = ('test_Data_sd_var',)
+#    test_only = ['test_Data_max_min_sum']
 #    test_only = ('test_Data___setitem__',)
 #    test_only = ('test_Data_ceil', 'test_Data_floor', 'test_Data_trunc', 'test_Data_rint')
 #    test_only = ('test_Data_array', 'test_Data_varray', 'test_Data_dtarray',)
@@ -454,16 +455,17 @@ class DataTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        for chunksize in self.chunk_sizes:   
-            cf.CHUNKSIZE(chunksize)          
-            d = cf.Data([[4, 5, 6], [1, 2, 3]], 'metre')
-            self.assertTrue(d.max() == cf.Data(6, 'metre'))
-            self.assertTrue(d.max().datum() == 6)
-            d[0, 2] = cf.masked
-            self.assertTrue(d.max() == 5)
-            self.assertTrue(d.max().datum() == 5)
-            self.assertTrue(d.max() == cf.Data(0.005, 'km'))
-#            print 'pmshape =', d._pmshape
+        for chunksize in self.chunk_sizes:
+            for pp in (False, True):
+                cf.CHUNKSIZE(chunksize)          
+                d = cf.Data([[4, 5, 6], [1, 2, 3]], 'metre')
+                self.assertTrue(d.max(_preserve_partitions=pp) == cf.Data(6, 'metre'))
+                self.assertTrue(d.max(_preserve_partitions=pp).datum() == 6)
+                d[0, 2] = cf.masked
+                self.assertTrue(d.max(_preserve_partitions=pp) == 5)
+                self.assertTrue(d.max(_preserve_partitions=pp).datum() == 5)
+                self.assertTrue(d.max(_preserve_partitions=pp) == cf.Data(0.005, 'km'))
+#               print 'pmshape =', d._pmshape
         #--- End: for
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
@@ -473,14 +475,15 @@ class DataTest(unittest.TestCase):
             return
 
         for chunksize in self.chunk_sizes:   
-            cf.CHUNKSIZE(chunksize)          
-            d = cf.Data([[4, 5, 6], [1, 2, 3]], 'metre')
-            self.assertTrue(d.min() == cf.Data(1, 'metre'))
-            self.assertTrue(d.min().datum() == 1)
-            d[1, 0] = cf.masked
-            self.assertTrue(d.min() == 2)
-            self.assertTrue(d.min().datum() == 2)
-            self.assertTrue(d.min() == cf.Data(0.002, 'km'))
+            for pp in (False, True):
+                cf.CHUNKSIZE(chunksize)          
+                d = cf.Data([[4, 5, 6], [1, 2, 3]], 'metre')
+                self.assertTrue(d.min(_preserve_partitions=pp) == cf.Data(1, 'metre'))
+                self.assertTrue(d.min(_preserve_partitions=pp).datum() == 1)
+                d[1, 0] = cf.masked
+                self.assertTrue(d.min(_preserve_partitions=pp) == 2)
+                self.assertTrue(d.min(_preserve_partitions=pp).datum() == 2)
+                self.assertTrue(d.min(_preserve_partitions=pp) == cf.Data(0.002, 'km'))
 #            print 'pmshape =', d._pmshape
 
         cf.CHUNKSIZE(self.original_chunksize)
@@ -888,7 +891,8 @@ class DataTest(unittest.TestCase):
                 shape = list(d.shape)
      
                 for axes in self.axes_combinations:
-                    e = getattr(d, h)(axes=axes, squeeze=False)
+                    e = getattr(d, h)(axes=axes, squeeze=False,
+                                      _preserve_partitions=False)
                     
                     shape = list(d.shape)
                     for i in axes:                        
@@ -902,7 +906,8 @@ class DataTest(unittest.TestCase):
                 #--- End: for
     
                 for axes in self.axes_combinations:
-                    e = getattr(d, h)(axes=axes, squeeze=True)
+                    e = getattr(d, h)(axes=axes, squeeze=True,
+                                      _preserve_partitions=False)
                     shape = list(d.shape)
                     for i in sorted(axes, reverse=True):                        
                         shape.pop(i)
@@ -913,14 +918,16 @@ class DataTest(unittest.TestCase):
                         (h, axis, e.shape, shape)
                 #--- End: for
     
-                e = getattr(d, h)(squeeze=True)
+                e = getattr(d, h)(squeeze=True,
+                                  _preserve_partitions=False)
                 shape = ()
                 self.assertTrue(
                     e.shape == shape,
                     "%s, axes=%s, squeezed bad shape: %s != %s" % \
                     (h, None, e.shape, shape))
     
-                e = getattr(d, h)(squeeze=False)
+                e = getattr(d, h)(squeeze=False,
+                                  _preserve_partitions=False)
                 shape = (1,) * d.ndim
                 self.assertTrue(
                     e.shape == shape,
@@ -939,41 +946,45 @@ class DataTest(unittest.TestCase):
             return
 
         for chunksize in self.chunk_sizes:   
-            cf.CHUNKSIZE(chunksize)          
-           
-            # unweighted, unmasked
-            d = cf.Data(self.a)
-            for np, h in zip((numpy.sum, numpy.amin, numpy.amax),
-                             (     'sum',     'min',     'max')):
-                for axes in self.axes_combinations:
-                    b = reshape_array(self.a, axes)
-                    b = np(b, axis=-1)                
-                    e = getattr(d, h)(axes=axes, squeeze=True)
-                    self.assertTrue(
-                        e.allclose(b, rtol=1e-05, atol=1e-08),
-                        "%s, axis=%s, unweighted, unmasked \ne=%s, \nb=%s, \ne-b=%s" %
-                        (h, axes, e.array, b, e.array-b))
-            #--- End: for
+            for pp in (True, False):
+                cf.CHUNKSIZE(chunksize)          
+               
+                # unweighted, unmasked
+                d = cf.Data(self.a)
+                for np, h in zip((numpy.sum, numpy.amin, numpy.amax),
+                                 (     'sum',     'min',     'max')):
+                    for axes in self.axes_combinations:
+                        b = reshape_array(self.a, axes)
+                        b = np(b, axis=-1)                
+                        e = getattr(d, h)(axes=axes, squeeze=True,
+                                          _preserve_partitions=pp)
+                        self.assertTrue(
+                            e.allclose(b, rtol=1e-05, atol=1e-08),
+                            "%s, axis=%s, unweighted, unmasked \ne=%s, \nb=%s, \ne-b=%s" %
+                            (h, axes, e.array, b, e.array-b))
+                #--- End: for
+        
+                # unweighted, masked
+                d = cf.Data(self.ma)
+                for np, h in zip((numpy.ma.sum, numpy.ma.amin, numpy.ma.amax),
+                                 (     'sum',     'min',     'max')):
+                    for axes in self.axes_combinations:
+                        b = reshape_array(self.ma, axes)
+                        b = np(b, axis=-1)                
+                        b = numpy.ma.asanyarray(b)
+                        e = getattr(d, h)(axes=axes, squeeze=True,
+                                          _preserve_partitions=pp)
+        
+                        self.assertTrue(
+                            (e.mask.array == b.mask).all(),
+                            "%s, axis=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
+                            (h, axes, e.mask.array, b.mask, e.mask.array==b.mask))
     
-            # unweighted, masked
-            d = cf.Data(self.ma)
-            for np, h in zip((numpy.ma.sum, numpy.ma.amin, numpy.ma.amax),
-                             (     'sum',     'min',     'max')):
-                for axes in self.axes_combinations:
-                    b = reshape_array(self.ma, axes)
-                    b = np(b, axis=-1)                
-                    b = numpy.ma.asanyarray(b)
-                    e = getattr(d, h)(axes=axes, squeeze=True)
-    
-                    self.assertTrue(
-                        (e.mask.array == b.mask).all(),
-                        "%s, axis=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
-                        (h, axes, e.mask.array, b.mask, e.mask.array==b.mask))
-
-                    self.assertTrue(
-                        e.allclose(b, rtol=1e-05, atol=1e-08),
-                        "%s, axis=%s, unweighted, masked \ne=%s, \nb=%s, \ne-b=%s" %
-                        (h, axes, e.array, b, e.array-b))
+                        self.assertTrue(
+                            e.allclose(b, rtol=1e-05, atol=1e-08),
+                            "%s, axis=%s, unweighted, masked \ne=%s, \nb=%s, \ne-b=%s" %
+                            (h, axes, e.array, b, e.array-b))
+                #--- End: for
             #--- End: for
         #--- End: for
 
@@ -986,78 +997,85 @@ class DataTest(unittest.TestCase):
 
         for chunksize in self.chunk_sizes:   
             cf.CHUNKSIZE(chunksize)          
-
-            # unweighted, masked
-            d = cf.Data(self.ma)
-            for a, h in zip((self.mones      , self.mones), 
-                            ('sum_of_weights', 'sum_of_weights2')):
-                for axes in self.axes_combinations:
-                    b = reshape_array(a, axes)
-                    b = numpy.ma.asanyarray(b.sum(axis=-1))
-                    e = getattr(d, h)(axes=axes, squeeze=True)  
+            for pp in (True, False):
+                # unweighted, masked
+                d = cf.Data(self.ma)
+                for a, h in zip((self.mones      , self.mones), 
+                                ('sum_of_weights', 'sum_of_weights2')):
+                    for axes in self.axes_combinations:
+                        b = reshape_array(a, axes)
+                        b = numpy.ma.asanyarray(b.sum(axis=-1))
+                        e = getattr(d, h)(axes=axes, squeeze=True,
+                                          _preserve_partitions=pp)  
+        
+                        self.assertTrue(
+                            (e.mask.array == b.mask).all(),
+                            "%s, axis=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
+                            (h, axes, e.mask.array, b.mask, e.mask.array==b.mask))
     
-                    self.assertTrue(
-                        (e.mask.array == b.mask).all(),
-                        "%s, axis=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
-                        (h, axes, e.mask.array, b.mask, e.mask.array==b.mask))
-
-                    self.assertTrue(
-                        e.allclose(b, rtol=1e-05, atol=1e-08),
-                        "%s, axis=%s, \ne=%s, \nb=%s, \ne-b=%s" %
-                        (h, axes, e.array, b, e.array-b))
+                        self.assertTrue(
+                            e.allclose(b, rtol=1e-05, atol=1e-08),
+                            "%s, axis=%s, \ne=%s, \nb=%s, \ne-b=%s" %
+                            (h, axes, e.array, b, e.array-b))
+                    #--- End: for
+    #                print "pmshape =", d._pmshape
+                #--- End: for    
+    
+                # unweighted, masked
+                d = cf.Data(self.a)
+                for h in ('sum_of_weights', 'sum_of_weights2'):
+                    for axes in self.axes_combinations:
+                        b = reshape_array(self.ones, axes)
+                        b = b.sum(axis=-1)
+                        e = getattr(d, h)(axes=axes, squeeze=True,
+                                          _preserve_partitions=pp)
+                        
+                        self.assertTrue(
+                            e.allclose(b, rtol=1e-05, atol=1e-08),
+                            "%s, axis=%s, \ne=%s, \nb=%s, \ne-b=%s" % \
+                            (h, axes, e.array, b, e.array-b))
                 #--- End: for
-#                print "pmshape =", d._pmshape
-            #--- End: for    
-
-            # unweighted, masked
-            d = cf.Data(self.a)
-            for h in ('sum_of_weights', 'sum_of_weights2'):
-                for axes in self.axes_combinations:
-                    b = reshape_array(self.ones, axes)
-                    b = b.sum(axis=-1)
-                    e = getattr(d, h)(axes=axes, squeeze=True)
-                    
-                    self.assertTrue(
-                        e.allclose(b, rtol=1e-05, atol=1e-08),
-                        "%s, axis=%s, \ne=%s, \nb=%s, \ne-b=%s" % \
-                        (h, axes, e.array, b, e.array-b))
-            #--- End: for
-
-            # weighted, masked
-            d = cf.Data(self.ma)
-            x = cf.Data(self.w)
-            for a, h in zip((self.mw         , self.mw*self.mw), 
-                            ('sum_of_weights', 'sum_of_weights2')):
-                for axes in self.axes_combinations:
-                    a = a.copy()
-                    a.mask = self.ma.mask
-                    b = reshape_array(a, axes)
-                    b = numpy.ma.asanyarray(b.sum(axis=-1))
-                    e = getattr(d, h)(axes=axes, weights=x, squeeze=True)  
-                    self.assertTrue(
-                        (e.mask.array == b.mask).all(),
-                        "%s, axis=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
-                        (h, axes, e.mask.array, b.mask, e.mask.array==b.mask))
-
-                    self.assertTrue(
-                        e.allclose(b, rtol=1e-05, atol=1e-08),
-                        "%s, axis=%s, \ne=%s, \nb=%s, \ne-b=%s" %
-                        (h, axes, e.array, b, e.array-b))
-            #--- End: for
     
-            # weighted, unmasked
-            d = cf.Data(self.a)
-            for a, h in zip((self.w          , self.w*self.w), 
-                            ('sum_of_weights', 'sum_of_weights2')):
-                for axes in self.axes_combinations:
-                    b = reshape_array(a, axes)
-                    b = b.sum(axis=-1)                
-                    e = getattr(d, h)(axes=axes, weights=x, squeeze=True)
-                    self.assertTrue(
-                        e.allclose(b, rtol=1e-05, atol=1e-08),
-                        "%s, axis=%s, \ne=%s, \nb=%s, \ne-b=%s" %
-                        (h, axes, e.array, b, e.array-b))
-            #--- End: for
+                # weighted, masked
+                d = cf.Data(self.ma)
+                x = cf.Data(self.w)
+                for a, h in zip((self.mw         , self.mw*self.mw), 
+                                ('sum_of_weights', 'sum_of_weights2')):
+                    for axes in self.axes_combinations:
+                        a = a.copy()
+                        a.mask = self.ma.mask
+                        b = reshape_array(a, axes)
+                        b = numpy.ma.asanyarray(b.sum(axis=-1))
+                        e = getattr(d, h)(axes=axes, weights=x,
+                                          squeeze=True,
+                                          _preserve_partitions=pp)
+                        self.assertTrue(
+                            (e.mask.array == b.mask).all(),
+                            "%s, axis=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
+                            (h, axes, e.mask.array, b.mask, e.mask.array==b.mask))
+    
+                        self.assertTrue(
+                            e.allclose(b, rtol=1e-05, atol=1e-08),
+                            "%s, axis=%s, \ne=%s, \nb=%s, \ne-b=%s" %
+                            (h, axes, e.array, b, e.array-b))
+                #--- End: for
+        
+                # weighted, unmasked
+                d = cf.Data(self.a)
+                for a, h in zip((self.w          , self.w*self.w), 
+                                ('sum_of_weights', 'sum_of_weights2')):
+                    for axes in self.axes_combinations:
+                        b = reshape_array(a, axes)
+                        b = b.sum(axis=-1)                
+                        e = getattr(d, h)(axes=axes, weights=x,
+                                          squeeze=True,
+                                          _preserve_partitions=pp)
+                        self.assertTrue(
+                            e.allclose(b, rtol=1e-05, atol=1e-08),
+                            "%s, axis=%s, \ne=%s, \nb=%s, \ne-b=%s" %
+                            (h, axes, e.array, b, e.array-b))
+                #--- End: for
+            #--- End: for    
         #--- End: for    
 
         cf.CHUNKSIZE(self.original_chunksize)
@@ -1183,134 +1201,143 @@ class DataTest(unittest.TestCase):
         f = 2
 
         for chunksize in self.chunk_sizes:   
-            cf.CHUNKSIZE(chunksize) 
+            for pp in (False, True):
+                cf.CHUNKSIZE(chunksize) 
 
-            # unweighted, unmasked
-            d = cf.Data(self.a, units='K')
-            for np, h in zip((numpy.var, numpy.std),
-                             ('var'    , 'sd')):
-                for ddof in ddofs:
-                    for axes in self.axes_combinations:
-                        b = reshape_array(self.a, axes)
-                        b = np(b, axis=-1, ddof=ddof)                
-                        e = getattr(d, h)(axes=axes, squeeze=True, ddof=ddof)
-                        self.assertTrue(
-                            e.allclose(b, rtol=1e-05, atol=1e-08),
-                            "%s, axis=%s, unweighted, unmasked \ne=%s, \nb=%s, \ne-b=%s" %
-                            (h, axes, e.array, b, e.array-b))
-            #--- End: for
-
-            # unweighted, masked
-            d = cf.Data(self.a, units='K')
-            x = cf.Data(self.w)
-            for h in ('var', 'sd'):
-                for axes in self.axes_combinations:                
+                # unweighted, unmasked
+                d = cf.Data(self.a, units='K')
+                for np, h in zip((numpy.var, numpy.std),
+                                 ('var'    , 'sd')):
                     for ddof in ddofs:
-                        e = getattr(d, h)(axes=axes, squeeze=True, ddof=ddof)
+                        for axes in self.axes_combinations:
+                            b = reshape_array(self.a, axes)
+                            b = np(b, axis=-1, ddof=ddof)                
+                            e = getattr(d, h)(axes=axes, squeeze=True,
+                                              ddof=ddof, _preserve_partitions=pp)
+                            self.assertTrue(
+                                e.allclose(b, rtol=1e-05, atol=1e-08),
+                                "%s, axis=%s, unweighted, unmasked \ne=%s, \nb=%s, \ne-b=%s" %
+                                (h, axes, e.array, b, e.array-b))
+                #--- End: for
     
-                        b = reshape_array(self.a, axes)
-    
-                        not_enough_data = numpy.ma.count(b, axis=-1) <= ddof
-    
-                        avg = numpy.ma.average(b, axis=-1)
-    
-                        if numpy.ndim(avg) < b.ndim:
-                            avg = numpy.ma.expand_dims(avg, -1)
-    
-                        b, sv = numpy.ma.average((b-avg)**2, axis=-1, returned=True)
-    
-                        b = numpy.ma.where(not_enough_data, numpy.ma.masked, b)
-    
-                        b *= sv/(sv-ddof)
-                        if h == 'sd':
-                            b **= 0.5
-                        b = numpy.ma.asanyarray(b)
-    
-                        e = getattr(d, h)(axes=axes, squeeze=True, ddof=ddof)
-                        
-                        self.assertTrue(
-                            (e.mask.array == b.mask).all(),
-                            "%s, axes=%s, ddof=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
-                            (h, axes, ddof, e.mask.array, b.mask, e.mask.array==b.mask))
-                        self.assertTrue(
-                            e.allclose(b, rtol=1e-05, atol=1e-08),
-                            "%s, axes=%s, ddof=%s, \ne=%s, \nb=%s, \ne-b=%s" %
-                            (h, axes, ddof, e.array, b, e.array-b))
-            #--- End: for
-
-            # weighted, unmasked 
-            f= 2
-            d = cf.Data(self.a, units='K')
-            x = cf.Data(self.w)
-            for h in ('var', 'sd'):
-                for axes in self.axes_combinations:                
-                    for ddof in ddofs:
-                        b = reshape_array(self.a, axes)
-                        v = reshape_array(self.w, axes)
-                        
-                        avg = numpy.average(b, axis=-1, weights=v)
-                        if numpy.ndim(avg) < b.ndim:
-                            avg = numpy.expand_dims(avg, -1)
+                # unweighted, masked
+                d = cf.Data(self.a, units='K')
+                x = cf.Data(self.w)
+                for h in ('var', 'sd'):
+                    for axes in self.axes_combinations:                
+                        for ddof in ddofs:
+                            e = getattr(d, h)(axes=axes, squeeze=True, ddof=ddof)
         
-                        b, sv = numpy.average((b-avg)**2, axis=-1, weights=v,
-                                              returned=True)
-                        b *= f*sv/(f*sv-ddof)
-                        
-                        if h == 'sd':
-                            b **= 0.5
+                            b = reshape_array(self.a, axes)
+        
+                            not_enough_data = numpy.ma.count(b, axis=-1) <= ddof
+        
+                            avg = numpy.ma.average(b, axis=-1)
+        
+                            if numpy.ndim(avg) < b.ndim:
+                                avg = numpy.ma.expand_dims(avg, -1)
+        
+                            b, sv = numpy.ma.average((b-avg)**2, axis=-1, returned=True)
+        
+                            b = numpy.ma.where(not_enough_data, numpy.ma.masked, b)
+        
+                            b *= sv/(sv-ddof)
+                            if h == 'sd':
+                                b **= 0.5
+                            b = numpy.ma.asanyarray(b)
+        
+                            e = getattr(d, h)(axes=axes, squeeze=True,
+                                              ddof=ddof,
+                                              _preserve_partitions=pp)
+                            
+                            self.assertTrue(
+                                (e.mask.array == b.mask).all(),
+                                "%s, axes=%s, ddof=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
+                                (h, axes, ddof, e.mask.array, b.mask, e.mask.array==b.mask))
+                            self.assertTrue(
+                                e.allclose(b, rtol=1e-05, atol=1e-08),
+                                "%s, axes=%s, ddof=%s, \ne=%s, \nb=%s, \ne-b=%s" %
+                                (h, axes, ddof, e.array, b, e.array-b))
+                #--- End: for
     
-                        e = getattr(d, h)(axes=axes, weights=x, squeeze=True,
-                                          ddof=ddof, a=f)
+                # weighted, unmasked 
+                f= 2
+                d = cf.Data(self.a, units='K')
+                x = cf.Data(self.w)
+                for h in ('var', 'sd'):
+                    for axes in self.axes_combinations:                
+                        for ddof in ddofs:
+                            b = reshape_array(self.a, axes)
+                            v = reshape_array(self.w, axes)
+                            
+                            avg = numpy.average(b, axis=-1, weights=v)
+                            if numpy.ndim(avg) < b.ndim:
+                                avg = numpy.expand_dims(avg, -1)
+            
+                            b, sv = numpy.average((b-avg)**2, axis=-1, weights=v,
+                                                  returned=True)
+                            b *= f*sv/(f*sv-ddof)
+                            
+                            if h == 'sd':
+                                b **= 0.5
+        
+                            e = getattr(d, h)(axes=axes, weights=x,
+                                              squeeze=True, ddof=ddof,
+                                              a=f,
+                                              _preserve_partitions=pp)
+        
+                            self.assertTrue(
+                                e.allclose(b, rtol=1e-05, atol=1e-08) ,
+                                "%s, axis=%s, ddof=%s, \ne=%s, \nb=%s, \ne-b=%s" % \
+                                (h, axes, ddof, e.array, b, e.array-b))
+                #--- End: for
     
-                        self.assertTrue(
-                            e.allclose(b, rtol=1e-05, atol=1e-08) ,
-                            "%s, axis=%s, ddof=%s, \ne=%s, \nb=%s, \ne-b=%s" % \
-                            (h, axes, ddof, e.array, b, e.array-b))
-            #--- End: for
-
-            # weighted, masked
-            f = 2
-            d = cf.Data(self.ma, units='K')
-            x = cf.Data(self.w)
-            for h in ('var', 'sd'):
-                for axes in self.axes_combinations:                
-                    for ddof in ddofs:
-                        b = reshape_array(self.ma, axes)
-                        v = reshape_array(self.mw, axes)
+                # weighted, masked
+                f = 2
+                d = cf.Data(self.ma, units='K')
+                x = cf.Data(self.w)
+                for h in ('var', 'sd'):
+                    for axes in self.axes_combinations:                
+                        for ddof in ddofs:
+                            b = reshape_array(self.ma, axes)
+                            v = reshape_array(self.mw, axes)
+        
+                            not_enough_data = numpy.ma.count(b, axis=-1) <= ddof
+        
+                            avg = numpy.ma.average(b, axis=-1, weights=v)
+                            if numpy.ndim(avg) < b.ndim:
+                                avg = numpy.ma.expand_dims(avg, -1)
+        
+                            b, sv = numpy.ma.average((b-avg)**2, axis=-1, weights=v,
+                                                     returned=True)
+        
+                            b = numpy.ma.where(not_enough_data, numpy.ma.masked, b)
+        
+                            b *= f*sv/(f*sv-ddof)
+                            if h == 'sd':
+                                b **= 0.5
+                            b = numpy.ma.asanyarray(b)
+        
+                            e = getattr(d, h)(axes=axes, weights=x,
+                                              squeeze=True, ddof=ddof,
+                                              a=f,
+                                              _preserve_partitions=pp)
+        
+                            if h == 'sd':
+                                self.assertTrue(e.Units == d.Units)
+                            else:                            
+                                self.assertTrue(e.Units == d.Units**2)
+                       
+                            self.assertTrue(
+                                (e.mask.array == b.mask).all(),
+                                "%s, axis=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
+                                (h, axes, e.mask.array, b.mask, e.mask.array==b.mask))
     
-                        not_enough_data = numpy.ma.count(b, axis=-1) <= ddof
-    
-                        avg = numpy.ma.average(b, axis=-1, weights=v)
-                        if numpy.ndim(avg) < b.ndim:
-                            avg = numpy.ma.expand_dims(avg, -1)
-    
-                        b, sv = numpy.ma.average((b-avg)**2, axis=-1, weights=v,
-                                                 returned=True)
-    
-                        b = numpy.ma.where(not_enough_data, numpy.ma.masked, b)
-    
-                        b *= f*sv/(f*sv-ddof)
-                        if h == 'sd':
-                            b **= 0.5
-                        b = numpy.ma.asanyarray(b)
-    
-                        e = getattr(d, h)(axes=axes, weights=x, squeeze=True,
-                                          ddof=ddof, a=f)
-    
-                        if h == 'sd':
-                            self.assertTrue(e.Units == d.Units)
-                        else:                            
-                            self.assertTrue(e.Units == d.Units**2)
-                   
-                        self.assertTrue(
-                            (e.mask.array == b.mask).all(),
-                            "%s, axis=%s, \ne.mask=%s, \nb.mask=%s, \ne.mask==b.mask=%s" %
-                            (h, axes, e.mask.array, b.mask, e.mask.array==b.mask))
-
-                        self.assertTrue(
-                            e.allclose(b, rtol=1e-05, atol=1e-08),
-                            "%s, axis=%s, ddof=%s, \ne=%s, \nb=%s, \ne-b=%s" %
-                            (h, axes, ddof, e.array, b, e.array-b))
+                            self.assertTrue(
+                                e.allclose(b, rtol=1e-05, atol=1e-08),
+                                "%s, axis=%s, ddof=%s, \ne=%s, \nb=%s, \ne-b=%s" %
+                                (h, axes, ddof, e.array, b, e.array-b))
+                #--- End: for
             #--- End: for
         #--- End: for
         cf.CHUNKSIZE(self.original_chunksize)
